==> ses_email_forwarding-3.0.2-py3-none-any.whl: package/lib/lambda/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __markAsModule = (target) => __defProp(target, "__esModule", {value: true});
var __commonJS = (callback, module2) => () => {
  if (!module2) {
    module2 = {exports: {}};
    callback(module2.exports, module2);
  }
  return module2.exports;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, {get: all[name], enumerable: true});
};
var __exportStar = (target, module2, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && key !== "default")
        __defProp(target, key, {get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable});
  }
  return target;
};
var __toModule = (module2) => {
  if (module2 && module2.__esModule)
    return module2;
  return __exportStar(__markAsModule(__defProp(module2 != null ? __create(__getProtoOf(module2)) : {}, "default", {value: module2, enumerable: true})), module2);
};

// node_modules/aws-lambda-ses-forwarder/index.js
var require_aws_lambda_ses_forwarder = __commonJS((exports2) => {
  "use strict";
  var AWS2 = require("aws-sdk");
  console.log("AWS Lambda SES Forwarder // @arithmetric // Version 5.0.0");
  var defaultConfig = {
    fromEmail: "noreply@example.com",
    subjectPrefix: "",
    emailBucket: "s3-bucket-name",
    emailKeyPrefix: "emailsPrefix/",
    allowPlusSign: true,
    forwardMapping: {
      "info@example.com": [
        "example.john@example.com",
        "example.jen@example.com"
      ],
      "abuse@example.com": [
        "example.jim@example.com"
      ],
      "@example.com": [
        "example.john@example.com"
      ],
      info: [
        "info@example.com"
      ]
    }
  };
  exports2.parseEvent = function(data) {
    if (!data.event || !data.event.hasOwnProperty("Records") || data.event.Records.length !== 1 || !data.event.Records[0].hasOwnProperty("eventSource") || data.event.Records[0].eventSource !== "aws:ses" || data.event.Records[0].eventVersion !== "1.0") {
      data.log({
        message: "parseEvent() received invalid SES message:",
        level: "error",
        event: JSON.stringify(data.event)
      });
      return Promise.reject(new Error("Error: Received invalid SES message."));
    }
    data.email = data.event.Records[0].ses.mail;
    data.recipients = data.event.Records[0].ses.receipt.recipients;
    return Promise.resolve(data);
  };
  exports2.transformRecipients = function(data) {
    var newRecipients = [];
    data.originalRecipients = data.recipients;
    data.recipients.forEach(function(origEmail) {
      var origEmailKey = origEmail.toLowerCase();
      if (data.config.allowPlusSign) {
        origEmailKey = origEmailKey.replace(/\+.*?@/, "@");
      }
      if (data.config.forwardMapping.hasOwnProperty(origEmailKey)) {
        newRecipients = newRecipients.concat(data.config.forwardMapping[origEmailKey]);
        data.originalRecipient = origEmail;
      } else {
        var origEmailDomain;
        var origEmailUser;
        var pos = origEmailKey.lastIndexOf("@");
        if (pos === -1) {
          origEmailUser = origEmailKey;
        } else {
          origEmailDomain = origEmailKey.slice(pos);
          origEmailUser = origEmailKey.slice(0, pos);
        }
        if (origEmailDomain && data.config.forwardMapping.hasOwnProperty(origEmailDomain)) {
          newRecipients = newRecipients.concat(data.config.forwardMapping[origEmailDomain]);
          data.originalRecipient = origEmail;
        } else if (origEmailUser && data.config.forwardMapping.hasOwnProperty(origEmailUser)) {
          newRecipients = newRecipients.concat(data.config.forwardMapping[origEmailUser]);
          data.originalRecipient = origEmail;
        } else if (data.config.forwardMapping.hasOwnProperty("@")) {
          newRecipients = newRecipients.concat(data.config.forwardMapping["@"]);
          data.originalRecipient = origEmail;
        }
      }
    });
    if (!newRecipients.length) {
      data.log({
        message: "Finishing process. No new recipients found for original destinations: " + data.originalRecipients.join(", "),
        level: "info"
      });
      return data.callback();
    }
    data.recipients = newRecipients;
    return Promise.resolve(data);
  };
  exports2.fetchMessage = function(data) {
    data.log({
      level: "info",
      message: "Fetching email at s3://" + data.config.emailBucket + "/" + data.config.emailKeyPrefix + data.email.messageId
    });
    return new Promise(function(resolve, reject) {
      data.s3.copyObject({
        Bucket: data.config.emailBucket,
        CopySource: data.config.emailBucket + "/" + data.config.emailKeyPrefix + data.email.messageId,
        Key: data.config.emailKeyPrefix + data.email.messageId,
        ACL: "private",
        ContentType: "text/plain",
        StorageClass: "STANDARD"
      }, function(err) {
        if (err) {
          data.log({
            level: "error",
            message: "copyObject() returned error:",
            error: err,
            stack: err.stack
          });
          return reject(new Error("Error: Could not make readable copy of email."));
        }
        data.s3.getObject({
          Bucket: data.config.emailBucket,
          Key: data.config.emailKeyPrefix + data.email.messageId
        }, function(err2, result) {
          if (err2) {
            data.log({
              level: "error",
              message: "getObject() returned error:",
              error: err2,
              stack: err2.stack
            });
            return reject(new Error("Error: Failed to load message body from S3."));
          }
          data.emailData = result.Body.toString();
          return resolve(data);
        });
      });
    });
  };
  exports2.processMessage = function(data) {
    var match = data.emailData.match(/^((?:.+\r?\n)*)(\r?\n(?:.*\s+)*)/m);
    var header = match && match[1] ? match[1] : data.emailData;
    var body = match && match[2] ? match[2] : "";
    if (!/^reply-to:[\t ]?/mi.test(header)) {
      match = header.match(/^from:[\t ]?(.*(?:\r?\n\s+.*)*\r?\n)/mi);
      var from = match && match[1] ? match[1] : "";
      if (from) {
        header = header + "Reply-To: " + from;
        data.log({
          level: "info",
          message: "Added Reply-To address of: " + from
        });
      } else {
        data.log({
          level: "info",
          message: "Reply-To address not added because From address was not properly extracted."
        });
      }
    }
    header = header.replace(/^from:[\t ]?(.*(?:\r?\n\s+.*)*)/mgi, function(match2, from2) {
      var fromText;
      if (data.config.fromEmail) {
        fromText = "From: " + from2.replace(/<(.*)>/, "").trim() + " <" + data.config.fromEmail + ">";
      } else {
        fromText = "From: " + from2.replace("<", "at ").replace(">", "") + " <" + data.originalRecipient + ">";
      }
      return fromText;
    });
    if (data.config.subjectPrefix) {
      header = header.replace(/^subject:[\t ]?(.*)/mgi, function(match2, subject) {
        return "Subject: " + data.config.subjectPrefix + subject;
      });
    }
    if (data.config.toEmail) {
      header = header.replace(/^to:[\t ]?(.*)/mgi, () => "To: " + data.config.toEmail);
    }
    header = header.replace(/^return-path:[\t ]?(.*)\r?\n/mgi, "");
    header = header.replace(/^sender:[\t ]?(.*)\r?\n/mgi, "");
    header = header.replace(/^message-id:[\t ]?(.*)\r?\n/mgi, "");
    header = header.replace(/^dkim-signature:[\t ]?.*\r?\n(\s+.*\r?\n)*/mgi, "");
    data.emailData = header + body;
    return Promise.resolve(data);
  };
  exports2.sendMessage = function(data) {
    var params = {
      Destinations: data.recipients,
      Source: data.originalRecipient,
      RawMessage: {
        Data: data.emailData
      }
    };
    data.log({
      level: "info",
      message: "sendMessage: Sending email via SES. Original recipients: " + data.originalRecipients.join(", ") + ". Transformed recipients: " + data.recipients.join(", ") + "."
    });
    return new Promise(function(resolve, reject) {
      data.ses.sendRawEmail(params, function(err, result) {
        if (err) {
          data.log({
            level: "error",
            message: "sendRawEmail() returned error.",
            error: err,
            stack: err.stack
          });
          return reject(new Error("Error: Email sending failed."));
        }
        data.log({
          level: "info",
          message: "sendRawEmail() successful.",
          result
        });
        resolve(data);
      });
    });
  };
  exports2.handler = function(event, context, callback, overrides) {
    var steps = overrides && overrides.steps ? overrides.steps : [
      exports2.parseEvent,
      exports2.transformRecipients,
      exports2.fetchMessage,
      exports2.processMessage,
      exports2.sendMessage
    ];
    var data = {
      event,
      callback,
      context,
      config: overrides && overrides.config ? overrides.config : defaultConfig,
      log: overrides && overrides.log ? overrides.log : console.log,
      ses: overrides && overrides.ses ? overrides.ses : new AWS2.SES(),
      s3: overrides && overrides.s3 ? overrides.s3 : new AWS2.S3({signatureVersion: "v4"})
    };
    Promise.series(steps, data).then(function(data2) {
      data2.log({
        level: "info",
        message: "Process finished successfully."
      });
      return data2.callback();
    }).catch(function(err) {
      data.log({
        level: "error",
        message: "Step returned error: " + err.message,
        error: err,
        stack: err.stack
      });
      return data.callback(new Error("Error: Step returned error."));
    });
  };
  Promise.series = function(promises, initValue) {
    return promises.reduce(function(chain, promise) {
      if (typeof promise !== "function") {
        return Promise.reject(new Error("Error: Invalid promise item: " + promise));
      }
      return chain.then(promise);
    }, Promise.resolve(initValue));
  };
});

// src/lambda/index.ts
__markAsModule(exports);
__export(exports, {
  handler: () => handler
});
var AWS = __toModule(require("aws-sdk"));
var forwarder = require_aws_lambda_ses_forwarder();
var ssm = new AWS.SSM();
var ssmKey = process.env.EMAIL_MAPPING_SSM_KEY;
var fromEmail = process.env.FROM_EMAIL;
var bucketName = process.env.BUCKET_NAME;
var bucketPrefix = process.env.BUCKET_PREFIX;
var isLoggingEnabled = process.env.ENABLE_LOGGING === "true";
var emailMapping = null;
function log(message, ...obj) {
  if (isLoggingEnabled) {
    console.log(message, ...obj);
  }
}
async function loadEmailMappingFromSsm() {
  var _a;
  if (!emailMapping) {
    const ssmValue = await ssm.getParameter({
      Name: ssmKey
    }).promise();
    if ((_a = ssmValue.Parameter) == null ? void 0 : _a.Value) {
      emailMapping = JSON.parse(ssmValue.Parameter.Value);
    }
  }
}
var handler = async (event, context) => {
  log("Received SES event : ", JSON.stringify(event));
  if (!ssmKey || !fromEmail || !bucketName) {
    const message = "Missing required environment variables. Either EMAIL_MAPPING_SSM_KEY, FROM_EMAIL or BUCKET_NAME is not set.";
    console.error(message);
    return Promise.reject(message);
  }
  await loadEmailMappingFromSsm();
  if (emailMapping) {
    const config = {
      fromEmail,
      emailBucket: bucketName,
      emailKeyPrefix: bucketPrefix,
      forwardMapping: emailMapping
    };
    log("Forwarding email with config: ", JSON.stringify(config));
    return new Promise((resolve, reject) => {
      forwarder.handler(event, context, (err) => {
        if (err) {
          reject();
        } else {
          resolve();
        }
      }, {config});
    });
  } else {
    log("Not forwarding mail. Reason: No email mapping found in SSM parameter " + ssmKey);
  }
  return Promise.resolve();
};

==> ses_email_forwarding-3.1.11-py3-none-any.whl: package/lib/lambda/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __markAsModule = (target) => __defProp(target, "__esModule", {value: true});
var __commonJS = (callback, module2) => () => {
  if (!module2) {
    module2 = {exports: {}};
    callback(module2.exports, module2);
  }
  return module2.exports;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, {get: all[name], enumerable: true});
};
var __exportStar = (target, module2, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && key !== "default")
        __defProp(target, key, {get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable});
  }
  return target;
};
var __toModule = (module2) => {
  return __exportStar(__markAsModule(__defProp(module2 != null ? __create(__getProtoOf(module2)) : {}, "default", module2 && module2.__esModule && "default" in module2 ? {get: () => module2.default, enumerable: true} : {value: module2, enumerable: true})), module2);
};

// node_modules/aws-lambda-ses-forwarder/index.js
var require_aws_lambda_ses_forwarder = __commonJS((exports2) => {
  "use strict";
  var AWS2 = require("aws-sdk");
  console.log("AWS Lambda SES Forwarder // @arithmetric // Version 5.0.0");
  var defaultConfig = {
    fromEmail: "noreply@example.com",
    subjectPrefix: "",
    emailBucket: "s3-bucket-name",
    emailKeyPrefix: "emailsPrefix/",
    allowPlusSign: true,
    forwardMapping: {
      "info@example.com": [
        "example.john@example.com",
        "example.jen@example.com"
      ],
      "abuse@example.com": [
        "example.jim@example.com"
      ],
      "@example.com": [
        "example.john@example.com"
      ],
      info: [
        "info@example.com"
      ]
    }
  };
  exports2.parseEvent = function(data) {
    if (!data.event || !data.event.hasOwnProperty("Records") || data.event.Records.length !== 1 || !data.event.Records[0].hasOwnProperty("eventSource") || data.event.Records[0].eventSource !== "aws:ses" || data.event.Records[0].eventVersion !== "1.0") {
      data.log({
        message: "parseEvent() received invalid SES message:",
        level: "error",
        event: JSON.stringify(data.event)
      });
      return Promise.reject(new Error("Error: Received invalid SES message."));
    }
    data.email = data.event.Records[0].ses.mail;
    data.recipients = data.event.Records[0].ses.receipt.recipients;
    return Promise.resolve(data);
  };
  exports2.transformRecipients = function(data) {
    var newRecipients = [];
    data.originalRecipients = data.recipients;
    data.recipients.forEach(function(origEmail) {
      var origEmailKey = origEmail.toLowerCase();
      if (data.config.allowPlusSign) {
        origEmailKey = origEmailKey.replace(/\+.*?@/, "@");
      }
      if (data.config.forwardMapping.hasOwnProperty(origEmailKey)) {
        newRecipients = newRecipients.concat(data.config.forwardMapping[origEmailKey]);
        data.originalRecipient = origEmail;
      } else {
        var origEmailDomain;
        var origEmailUser;
        var pos = origEmailKey.lastIndexOf("@");
        if (pos === -1) {
          origEmailUser = origEmailKey;
        } else {
          origEmailDomain = origEmailKey.slice(pos);
          origEmailUser = origEmailKey.slice(0, pos);
        }
        if (origEmailDomain && data.config.forwardMapping.hasOwnProperty(origEmailDomain)) {
          newRecipients = newRecipients.concat(data.config.forwardMapping[origEmailDomain]);
          data.originalRecipient = origEmail;
        } else if (origEmailUser && data.config.forwardMapping.hasOwnProperty(origEmailUser)) {
          newRecipients = newRecipients.concat(data.config.forwardMapping[origEmailUser]);
          data.originalRecipient = origEmail;
        } else if (data.config.forwardMapping.hasOwnProperty("@")) {
          newRecipients = newRecipients.concat(data.config.forwardMapping["@"]);
          data.originalRecipient = origEmail;
        }
      }
    });
    if (!newRecipients.length) {
      data.log({
        message: "Finishing process. No new recipients found for original destinations: " + data.originalRecipients.join(", "),
        level: "info"
      });
      return data.callback();
    }
    data.recipients = newRecipients;
    return Promise.resolve(data);
  };
  exports2.fetchMessage = function(data) {
    data.log({
      level: "info",
      message: "Fetching email at s3://" + data.config.emailBucket + "/" + data.config.emailKeyPrefix + data.email.messageId
    });
    return new Promise(function(resolve, reject) {
      data.s3.copyObject({
        Bucket: data.config.emailBucket,
        CopySource: data.config.emailBucket + "/" + data.config.emailKeyPrefix + data.email.messageId,
        Key: data.config.emailKeyPrefix + data.email.messageId,
        ACL: "private",
        ContentType: "text/plain",
        StorageClass: "STANDARD"
      }, function(err) {
        if (err) {
          data.log({
            level: "error",
            message: "copyObject() returned error:",
            error: err,
            stack: err.stack
          });
          return reject(new Error("Error: Could not make readable copy of email."));
        }
        data.s3.getObject({
          Bucket: data.config.emailBucket,
          Key: data.config.emailKeyPrefix + data.email.messageId
        }, function(err2, result) {
          if (err2) {
            data.log({
              level: "error",
              message: "getObject() returned error:",
              error: err2,
              stack: err2.stack
            });
            return reject(new Error("Error: Failed to load message body from S3."));
          }
          data.emailData = result.Body.toString();
          return resolve(data);
        });
      });
    });
  };
  exports2.processMessage = function(data) {
    var match = data.emailData.match(/^((?:.+\r?\n)*)(\r?\n(?:.*\s+)*)/m);
    var header = match && match[1] ? match[1] : data.emailData;
    var body = match && match[2] ? match[2] : "";
    if (!/^reply-to:[\t ]?/mi.test(header)) {
      match = header.match(/^from:[\t ]?(.*(?:\r?\n\s+.*)*\r?\n)/mi);
      var from = match && match[1] ? match[1] : "";
      if (from) {
        header = header + "Reply-To: " + from;
        data.log({
          level: "info",
          message: "Added Reply-To address of: " + from
        });
      } else {
        data.log({
          level: "info",
          message: "Reply-To address not added because From address was not properly extracted."
        });
      }
    }
    header = header.replace(/^from:[\t ]?(.*(?:\r?\n\s+.*)*)/mgi, function(match2, from2) {
      var fromText;
      if (data.config.fromEmail) {
        fromText = "From: " + from2.replace(/<(.*)>/, "").trim() + " <" + data.config.fromEmail + ">";
      } else {
        fromText = "From: " + from2.replace("<", "at ").replace(">", "") + " <" + data.originalRecipient + ">";
      }
      return fromText;
    });
    if (data.config.subjectPrefix) {
      header = header.replace(/^subject:[\t ]?(.*)/mgi, function(match2, subject) {
        return "Subject: " + data.config.subjectPrefix + subject;
      });
    }
    if (data.config.toEmail) {
      header = header.replace(/^to:[\t ]?(.*)/mgi, () => "To: " + data.config.toEmail);
    }
    header = header.replace(/^return-path:[\t ]?(.*)\r?\n/mgi, "");
    header = header.replace(/^sender:[\t ]?(.*)\r?\n/mgi, "");
    header = header.replace(/^message-id:[\t ]?(.*)\r?\n/mgi, "");
    header = header.replace(/^dkim-signature:[\t ]?.*\r?\n(\s+.*\r?\n)*/mgi, "");
    data.emailData = header + body;
    return Promise.resolve(data);
  };
  exports2.sendMessage = function(data) {
    var params = {
      Destinations: data.recipients,
      Source: data.originalRecipient,
      RawMessage: {
        Data: data.emailData
      }
    };
    data.log({
      level: "info",
      message: "sendMessage: Sending email via SES. Original recipients: " + data.originalRecipients.join(", ") + ". Transformed recipients: " + data.recipients.join(", ") + "."
    });
    return new Promise(function(resolve, reject) {
      data.ses.sendRawEmail(params, function(err, result) {
        if (err) {
          data.log({
            level: "error",
            message: "sendRawEmail() returned error.",
            error: err,
            stack: err.stack
          });
          return reject(new Error("Error: Email sending failed."));
        }
        data.log({
          level: "info",
          message: "sendRawEmail() successful.",
          result
        });
        resolve(data);
      });
    });
  };
  exports2.handler = function(event, context, callback, overrides) {
    var steps = overrides && overrides.steps ? overrides.steps : [
      exports2.parseEvent,
      exports2.transformRecipients,
      exports2.fetchMessage,
      exports2.processMessage,
      exports2.sendMessage
    ];
    var data = {
      event,
      callback,
      context,
      config: overrides && overrides.config ? overrides.config : defaultConfig,
      log: overrides && overrides.log ? overrides.log : console.log,
      ses: overrides && overrides.ses ? overrides.ses : new AWS2.SES(),
      s3: overrides && overrides.s3 ? overrides.s3 : new AWS2.S3({signatureVersion: "v4"})
    };
    Promise.series(steps, data).then(function(data2) {
      data2.log({
        level: "info",
        message: "Process finished successfully."
      });
      return data2.callback();
    }).catch(function(err) {
      data.log({
        level: "error",
        message: "Step returned error: " + err.message,
        error: err,
        stack: err.stack
      });
      return data.callback(new Error("Error: Step returned error."));
    });
  };
  Promise.series = function(promises, initValue) {
    return promises.reduce(function(chain, promise) {
      if (typeof promise !== "function") {
        return Promise.reject(new Error("Error: Invalid promise item: " + promise));
      }
      return chain.then(promise);
    }, Promise.resolve(initValue));
  };
});

// src/lambda/index.ts
__markAsModule(exports);
__export(exports, {
  handler: () => handler
});
var AWS = __toModule(require("aws-sdk"));
var forwarder = require_aws_lambda_ses_forwarder();
var ssm = new AWS.SSM();
var ssmKey = process.env.EMAIL_MAPPING_SSM_KEY;
var fromEmail = process.env.FROM_EMAIL;
var bucketName = process.env.BUCKET_NAME;
var bucketPrefix = process.env.BUCKET_PREFIX;
var isLoggingEnabled = process.env.ENABLE_LOGGING === "true";
var emailMapping = null;
function log(message, ...obj) {
  if (isLoggingEnabled) {
    console.log(message, ...obj);
  }
}
async function loadEmailMappingFromSsm() {
  var _a;
  if (!emailMapping) {
    const ssmValue = await ssm.getParameter({
      Name: ssmKey
    }).promise();
    if ((_a = ssmValue.Parameter) == null ? void 0 : _a.Value) {
      emailMapping = JSON.parse(ssmValue.Parameter.Value);
    }
  }
}
var handler = async (event, context) => {
  log("Received SES event : ", JSON.stringify(event));
  if (!ssmKey || !fromEmail || !bucketName) {
    const message = "Missing required environment variables. Either EMAIL_MAPPING_SSM_KEY, FROM_EMAIL or BUCKET_NAME is not set.";
    console.error(message);
    return Promise.reject(message);
  }
  await loadEmailMappingFromSsm();
  if (emailMapping) {
    const config = {
      fromEmail,
      emailBucket: bucketName,
      emailKeyPrefix: bucketPrefix,
      forwardMapping: emailMapping
    };
    log("Forwarding email with config: ", JSON.stringify(config));
    return new Promise((resolve, reject) => {
      forwarder.handler(event, context, (err) => {
        if (err) {
          reject();
        } else {
          resolve();
        }
      }, {config});
    });
  } else {
    log("Not forwarding mail. Reason: No email mapping found in SSM parameter " + ssmKey);
  }
  return Promise.resolve();
};
